package com.dcsoft.system.visitor.service;

import com.dcsoft.system.visitor.domain.VisVisitorExamine;

import java.util.List;

/**
 * 访客审核Service接口
 *
 * @author nichun
 * @date 2023-03-11
 */
public interface IVisVisitorExamineService
{
    /**
     * 查询访客审核
     *
     * @param id 访客审核主键
     * @return 访客审核
     */
    public VisVisitorExamine selectVisVisitorExamineById(Long id);

    /**
     * 查询访客审核列表
     *
     * @param visVisitorExamine 访客审核
     * @return 访客审核集合
     */
    public List<VisVisitorExamine> selectVisVisitorExamineList(VisVisitorExamine visVisitorExamine);

    /**
     * 新增访客审核
     *
     * @param visVisitorExamine 访客审核
     * @return 结果
     */
    public int insertVisVisitorExamine(VisVisitorExamine visVisitorExamine);

    /**
     * 修改访客审核
     *
     * @param visVisitorExamine 访客审核
     * @return 结果
     */
    public int updateVisVisitorExamine(VisVisitorExamine visVisitorExamine);

    /**
     * 批量删除访客审核
     *
     * @param ids 需要删除的访客审核主键集合
     * @return 结果
     */
    public int deleteVisVisitorExamineByIds(Long[] ids);

    /**
     * 删除访客审核信息
     *
     * @param id 访客审核主键
     * @return 结果
     */
    public int deleteVisVisitorExamineById(Long id);

    /**
     * 删除访客审核信息
     *
     * @param visitorId 访客审核主键
     * @return 结果
     */
    public int deleteVisVisitorExamineByVisitorId(Long visitorId);

}
